modular_decomposition: A modular decomposition algorithm
========================================================

Description
-----------

This is an implementation of a modular decomposition algorithm.

http://www.liafa.jussieu.fr/~fm/ (in french)

License
-------

GPL


Upstream Contact
----------------

Fabien de Montgolfier

http://www.liafa.jussieu.fr/~fm/

Dependencies
------------

None

Patches
-------

None
